@@ -718,6 +718,8 @@ def test_event_processor_drop_records_client_report(
         (["quart"], "sentry.python.quart"),
         (["sanic"], "sentry.python.sanic"),
         (["starlette"], "sentry.python.starlette"),
+        (["starlite"], "sentry.python.starlite"),
+        (["litestar"], "sentry.python.litestar"),
         (["chalice"], "sentry.python.chalice"),
         (["serverless"], "sentry.python.serverless"),
         (["pyramid"], "sentry.python.pyramid"),
@@ -756,6 +758,8 @@ def test_event_processor_drop_records_client_report(
         (["sanic", "quart", "sqlalchemy"], "sentry.python.quart"),
         (["starlette", "sanic", "rq"], "sentry.python.sanic"),
         (["chalice", "starlette", "modules"], "sentry.python.starlette"),
+        (["chalice", "starlite", "modules"], "sentry.python.starlite"),
+        (["chalice", "litestar", "modules"], "sentry.python.litestar"),
         (["serverless", "chalice", "pure_eval"], "sentry.python.chalice"),
         (["pyramid", "serverless", "modules"], "sentry.python.serverless"),
         (["tornado", "pyramid", "executing"], "sentry.python.pyramid"),
